@@ -1,35 +1,20 @@
 /*
-    Copyright (c) 2013 Christian Mollekopf <mollekopf@kolabsys.com>
+    SPDX-FileCopyrightText: 2013 Christian Mollekopf <mollekopf@kolabsys.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QObject>
 
-#include "test_utils.h"
-
-#include <entitytreemodel.h>
-#include <control.h>
-#include <entitytreemodel_p.h>
-#include <monitor_p.h>
-#include <changerecorder_p.h>
-#include <qtest_akonadi.h>
-#include <collectioncreatejob.h>
-#include <collectiondeletejob.h>
-#include <itemcreatejob.h>
+#include "entitytreemodel.h"
+#include "control.h"
+#include "entitytreemodel_p.h"
+#include "monitor_p.h"
+#include "changerecorder_p.h"
+#include "qtest_akonadi.h"
+#include "collectioncreatejob.h"
+#include "collectiondeletejob.h"
+#include "itemcreatejob.h"
 
 using namespace Akonadi;
 
@@ -69,7 +54,7 @@ public Q_SLOTS:
         start = s;
         end = e;
     }
-    void onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
+    void onRowsMoved(const QModelIndex & /*unused*/, int /*unused*/, int /*unused*/, const QModelIndex & /*unused*/, int /*unused*/)
     {
         mSignals << QStringLiteral("rowsMoved");
     }
@@ -157,7 +142,7 @@ void EtmPopulationTest::initTestCase()
     AkonadiTest::checkTestIsIsolated();
     AkonadiTest::setAllResourcesOffline();
 
-    res = Collection(collectionIdFromPath(QStringLiteral("res3")));
+    res = Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res3")));
 
     mainCollectionName = QStringLiteral("main");
     monitorCol = createCollection(mainCollectionName, res);
@@ -177,6 +162,7 @@ void EtmPopulationTest::testMonitoringCollectionsPreset()
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     changeRecorder->setCollectionMonitored(col1, true);
     changeRecorder->setCollectionMonitored(col2, true);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
@@ -197,6 +183,7 @@ void EtmPopulationTest::testMonitoringCollectionsPreset()
 void EtmPopulationTest::testMonitoringCollections()
 {
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
@@ -222,6 +209,7 @@ void EtmPopulationTest::testFullPopulation()
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     // changeRecorder->setCollectionMonitored(Akonadi::Collection::root());
     changeRecorder->setAllMonitored(true);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
@@ -244,6 +232,7 @@ void EtmPopulationTest::testAddMonitoringCollections()
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     changeRecorder->setCollectionMonitored(col1, true);
     changeRecorder->setCollectionMonitored(col2, true);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
@@ -272,6 +261,7 @@ void EtmPopulationTest::testRemoveMonitoringCollections()
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     changeRecorder->setCollectionMonitored(col1, true);
     changeRecorder->setCollectionMonitored(col2, true);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
@@ -301,6 +291,7 @@ void EtmPopulationTest::testDisplayFilter()
 
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
     model->setListFilter(Akonadi::CollectionFetchScope::Display);
@@ -327,6 +318,7 @@ void EtmPopulationTest::testLoadingOfHiddenCollection()
 
     ChangeRecorder *changeRecorder = new ChangeRecorder(this);
     changeRecorder->setMimeTypeMonitored(QStringLiteral("application/test"), true);
+    AkonadiTest::akWaitForSignal(changeRecorder, &Monitor::monitorReady);
     InspectableETM *model = new InspectableETM(changeRecorder, this);
     model->setItemPopulationStrategy(EntityTreeModel::ImmediatePopulation);
     model->setCollectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive);
