@@ -1,19 +1,7 @@
 /*
-  Copyright (C) 2009 Stephen Kelly <steveire@gmail.com>
+  SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "fakeakonadiservercommand.h"
@@ -57,8 +45,9 @@ bool FakeAkonadiServerCommand::isCollectionSignal(const QByteArray &signal) cons
 
 void FakeAkonadiServerCommand::connectForwardingSignals()
 {
-    for (int methodIndex = 0; methodIndex < metaObject()->methodCount(); ++methodIndex) {
-        const QMetaMethod mm = metaObject()->method(methodIndex);
+    const auto *mo = FakeAkonadiServerCommand::metaObject();
+    for (int methodIndex = 0; methodIndex < mo->methodCount(); ++methodIndex) {
+        const QMetaMethod mm = mo->method(methodIndex);
         QByteArray signature = mm.methodSignature();
         if (mm.methodType() == QMetaMethod::Signal) {
             if ((qobject_cast<TagModel*>(m_model) && isTagSignal(signature)) ||
@@ -66,7 +55,7 @@ void FakeAkonadiServerCommand::connectForwardingSignals()
             {
                 const int modelSlotIndex = m_model->metaObject()->indexOfSlot(signature.remove(0, 5).constData());
                 Q_ASSERT(modelSlotIndex >= 0);
-                metaObject()->connect(this, methodIndex, m_model, modelSlotIndex);
+                mo->connect(this, methodIndex, m_model, modelSlotIndex);
             }
         }
     }
