@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006-2008 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006-2008 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "agentmanager.h"
@@ -313,32 +300,22 @@ void AgentManagerPrivate::createDBusInterface()
 {
     mTypes.clear();
     mInstances.clear();
-    delete mManager;
 
-    mManager = new org::freedesktop::Akonadi::AgentManager(ServerManager::serviceName(ServerManager::Control),
+    using AgentManagerIface = org::freedesktop::Akonadi::AgentManager;
+    mManager = std::make_unique<AgentManagerIface>(ServerManager::serviceName(ServerManager::Control),
             QStringLiteral("/AgentManager"),
             QDBusConnection::sessionBus(), mParent);
 
-    QObject::connect(mManager, SIGNAL(agentTypeAdded(QString)),
-                     mParent, SLOT(agentTypeAdded(QString)));
-    QObject::connect(mManager, SIGNAL(agentTypeRemoved(QString)),
-                     mParent, SLOT(agentTypeRemoved(QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceAdded(QString)),
-                     mParent, SLOT(agentInstanceAdded(QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceRemoved(QString)),
-                     mParent, SLOT(agentInstanceRemoved(QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceStatusChanged(QString,int,QString)),
-                     mParent, SLOT(agentInstanceStatusChanged(QString,int,QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceProgressChanged(QString,uint,QString)),
-                     mParent, SLOT(agentInstanceProgressChanged(QString,uint,QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceNameChanged(QString,QString)),
-                     mParent, SLOT(agentInstanceNameChanged(QString,QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceWarning(QString,QString)),
-                     mParent, SLOT(agentInstanceWarning(QString,QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceError(QString,QString)),
-                     mParent, SLOT(agentInstanceError(QString,QString)));
-    QObject::connect(mManager, SIGNAL(agentInstanceOnlineChanged(QString,bool)),
-                     mParent, SLOT(agentInstanceOnlineChanged(QString,bool)));
+    connect(mManager.get(), &AgentManagerIface::agentTypeAdded, this, &AgentManagerPrivate::agentTypeAdded);
+    connect(mManager.get(), &AgentManagerIface::agentTypeRemoved, this, &AgentManagerPrivate::agentTypeRemoved);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceAdded, this, &AgentManagerPrivate::agentInstanceAdded);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceRemoved, this, &AgentManagerPrivate::agentInstanceRemoved);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceStatusChanged, this, &AgentManagerPrivate::agentInstanceStatusChanged);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceProgressChanged, this, &AgentManagerPrivate::agentInstanceProgressChanged);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceNameChanged, this, &AgentManagerPrivate::agentInstanceNameChanged);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceWarning, this, &AgentManagerPrivate::agentInstanceWarning);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceError, this, &AgentManagerPrivate::agentInstanceError);
+    connect(mManager.get(), &AgentManagerIface::agentInstanceOnlineChanged, this, &AgentManagerPrivate::agentInstanceOnlineChanged);
 
     if (mManager->isValid()) {
         readAgentTypes();
@@ -374,10 +351,7 @@ AgentManager::AgentManager()
 
 // @endcond
 
-AgentManager::~AgentManager()
-{
-    delete d;
-}
+AgentManager::~AgentManager() = default;
 
 AgentManager *AgentManager::self()
 {
