@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "item.h"
@@ -29,6 +16,7 @@
 
 #include <QStringList>
 #include <QReadWriteLock>
+#include <QScopedValueRollback>
 
 #include <algorithm>
 #include <map>
@@ -36,109 +24,13 @@
 
 using namespace Akonadi;
 
-Q_GLOBAL_STATIC(Akonadi::Collection, s_defaultParentCollection)
+Q_GLOBAL_STATIC(Akonadi::Collection, s_defaultParentCollection) // NOLINT(readability-redundant-member-init)
 
 uint Akonadi::qHash(const Akonadi::Item &item)
 {
     return ::qHash(item.id());
 }
 
-namespace
-{
-
-struct ByTypeId {
-    typedef bool result_type;
-    bool operator()(const std::shared_ptr<Internal::PayloadBase> &lhs,
-                    const std::shared_ptr<Internal::PayloadBase> &rhs) const
-    {
-        return strcmp(lhs->typeName(), rhs->typeName()) < 0;
-    }
-};
-
-} // anon namespace
-
-typedef QHash<QString, std::map<std::shared_ptr<Internal::PayloadBase>, std::pair<int, int>, ByTypeId>> LegacyMap;
-Q_GLOBAL_STATIC(LegacyMap, typeInfoToMetaTypeIdMap)
-Q_GLOBAL_STATIC_WITH_ARGS(QReadWriteLock, legacyMapLock, (QReadWriteLock::Recursive))
-
-void Item::addToLegacyMappingImpl(const QString &mimeType, int spid, int mtid,
-                                  std::unique_ptr<Internal::PayloadBase> &p)
-{
-    if (!p.get()) {
-        return;
-    }
-    const std::shared_ptr<Internal::PayloadBase> sp(p.release());
-    const QWriteLocker locker(legacyMapLock());
-    std::pair<int, int> &item = (*typeInfoToMetaTypeIdMap())[mimeType][sp];
-    item.first = spid;
-    item.second = mtid;
-}
-
-namespace
-{
-class MyReadLocker
-{
-public:
-    explicit MyReadLocker(QReadWriteLock *rwl)
-        : rwl(rwl)
-        , locked(false)
-    {
-        if (rwl) {
-            rwl->lockForRead();
-        }
-        locked = true;
-    }
-
-    ~MyReadLocker()
-    {
-        if (rwl && locked) {
-            rwl->unlock();
-        }
-    }
-
-    template <typename T>
-    std::shared_ptr<T> makeUnlockingPointer(T *t)
-    {
-        if (t) {
-            // the bind() doesn't throw, so if shared_ptr
-            // construction line below, or anything else after it,
-            // throws, we're unlocked. Mark us as such:
-            locked = false;
-            const std::shared_ptr<T> result(t, [&](const void *) {
-                rwl->unlock();
-            });
-            // from now on, the shared_ptr is responsible for unlocking
-            return result;
-        } else {
-            return std::shared_ptr<T>();
-        }
-    }
-private:
-    Q_DISABLE_COPY(MyReadLocker)
-    QReadWriteLock *const rwl;
-    bool locked;
-};
-}
-
-static std::shared_ptr<const std::pair<int, int>> lookupLegacyMapping(const QString &mimeType,
-        Internal::PayloadBase *p)
-{
-    MyReadLocker locker(legacyMapLock());
-    const LegacyMap::const_iterator hit = typeInfoToMetaTypeIdMap()->constFind(mimeType);
-    if (hit == typeInfoToMetaTypeIdMap()->constEnd()) {
-        return std::shared_ptr<const std::pair<int, int>>();
-    }
-    const std::shared_ptr<Internal::PayloadBase> sp(p, [ = ](Internal::PayloadBase *) {
-        /*noop*/
-    });
-    const LegacyMap::mapped_type::const_iterator it = hit->find(sp);
-    if (it == hit->end()) {
-        return std::shared_ptr<const std::pair<int, int>>();
-    }
-
-    return locker.makeUnlockingPointer(&it->second);
-}
-
 // Change to something != RFC822 as soon as the server supports it
 const char Item::FullPayload[] = "RFC822";
 
@@ -158,14 +50,11 @@ Item::Item(const QString &mimeType)
     d_ptr->mMimeType = mimeType;
 }
 
-Item::Item(const Item &other)
-    : d_ptr(other.d_ptr)
-{
-}
+Item::Item(const Item &other) = default;
 
-Item::~Item()
-{
-}
+Item::Item(Item &&other) noexcept = default;
+
+Item::~Item() = default;
 
 void Item::setId(Item::Id identifier)
 {
@@ -265,7 +154,7 @@ const Attribute *Item::attribute(const QByteArray &type) const
 Collection &Item::parentCollection()
 {
     if (!d_ptr->mParent) {
-        d_ptr->mParent = new Collection();
+        d_ptr->mParent.reset(new Collection());
     }
     return *(d_ptr->mParent);
 }
@@ -281,8 +170,7 @@ Collection Item::parentCollection() const
 
 void Item::setParentCollection(const Collection &parent)
 {
-    delete d_ptr->mParent;
-    d_ptr->mParent = new Collection(parent);
+    d_ptr->mParent.reset(new Collection(parent));
 }
 
 Item::Flags Item::flags() const
@@ -517,63 +405,11 @@ Item Item::fromUrl(const QUrl &url)
     return Item(itemId);
 }
 
-namespace
-{
-class Dummy
-{
-};
-}
-
-Q_GLOBAL_STATIC(Internal::Payload<Dummy>, dummyPayload)
-
-Internal::PayloadBase *Item::payloadBase() const
-{
-    d_ptr->tryEnsureLegacyPayload();
-    if (d_ptr->mLegacyPayload) {
-        return d_ptr->mLegacyPayload.get();
-    } else {
-        return dummyPayload();
-    }
-}
-
-void ItemPrivate::tryEnsureLegacyPayload() const
-{
-    if (!mLegacyPayload) {
-        for (PayloadContainer::const_iterator it = mPayloads.begin(), end = mPayloads.end(); it != end; ++it) {
-            if (lookupLegacyMapping(mMimeType, it->payload.get())) {
-                mLegacyPayload = it->payload; // clones
-            }
-        }
-    }
-}
-
 Internal::PayloadBase *Item::payloadBaseV2(int spid, int mtid) const
 {
     return d_ptr->payloadBaseImpl(spid, mtid);
 }
 
-namespace
-{
-class ConversionGuard
-{
-    const bool old;
-    bool &b;
-public:
-    explicit ConversionGuard(bool &b)
-        : old(b)
-        , b(b)
-    {
-        b = true;
-    }
-    ~ConversionGuard()
-    {
-        b = old;
-    }
-private:
-    Q_DISABLE_COPY(ConversionGuard)
-};
-}
-
 bool Item::ensureMetaTypeId(int mtid) const
 {
     // 0. Nothing there - nothing to convert from, either
@@ -594,14 +430,14 @@ bool Item::ensureMetaTypeId(int mtid) const
 
     // 2. Try to create one by conversion from a different representation:
     try {
-        const ConversionGuard guard(d_ptr->mConversionInProgress);
+        const QScopedValueRollback guard(d_ptr->mConversionInProgress, true);
         Item converted = ItemSerializer::convert(*this, mtid);
         return d_ptr->movePayloadFrom(converted.d_ptr, mtid);
     } catch (const std::exception &e) {
-        qCDebug(AKONADICORE_LOG) << "conversion threw:" << e.what();
+        qCWarning(AKONADICORE_LOG) << "Item payload conversion threw:" << e.what();
         return false;
     } catch (...) {
-        qCDebug(AKONADICORE_LOG) << "conversion threw something not derived from std::exception: fix the program!";
+        qCCritical(AKONADICORE_LOG, "conversion threw something not derived from std::exception: fix the program!");
         return false;
     }
 }
@@ -622,17 +458,6 @@ static QString format_types(const PayloadContainer &c)
     return result.join(QLatin1String(", "));
 }
 
-#if 0
-QString Item::payloadExceptionText(int spid, int mtid) const
-{
-    if (d_ptr->mPayloads.empty()) {
-        return QStringLiteral("No payload set");
-    } else {
-        return QStringLiteral("Wrong payload type (requested: %1; present: %2")
-               .arg(format_type(spid, mtid), format_types(d_ptr->mPayloads));
-    }
-}
-#else
 void Item::throwPayloadException(int spid, int mtid) const
 {
     if (d_ptr->mPayloads.empty()) {
@@ -645,27 +470,6 @@ void Item::throwPayloadException(int spid, int mtid) const
                                .arg(format_type(spid, mtid), format_types(d_ptr->mPayloads)));
     }
 }
-#endif
-
-void Item::setPayloadBase(Internal::PayloadBase *p)
-{
-    d_ptr->setLegacyPayloadBaseImpl(std::unique_ptr<Internal::PayloadBase>(p));
-}
-
-void ItemPrivate::setLegacyPayloadBaseImpl(std::unique_ptr<Internal::PayloadBase> p)
-{
-    if (const std::shared_ptr<const std::pair<int, int>> pair = lookupLegacyMapping(mMimeType, p.get())) {
-        std::unique_ptr<Internal::PayloadBase> clone;
-        if (p.get()) {
-            clone.reset(p->clone());
-        }
-        setPayloadBaseImpl(pair->first, pair->second, p, false);
-        mLegacyPayload.reset(clone.release());
-    } else {
-        mPayloads.clear();
-        mLegacyPayload.reset(p.release());
-    }
-}
 
 void Item::setPayloadBaseV2(int spid, int mtid, std::unique_ptr<Internal::PayloadBase> &p)
 {
@@ -697,7 +501,7 @@ QVector<int> Item::availablePayloadMetaTypeIds() const
     QVector<int> result;
     result.reserve(d_ptr->mPayloads.size());
     // Stable Insertion Sort - N is typically _very_ low (1 or 2).
-    for (PayloadContainer::const_iterator it = d_ptr->mPayloads.begin(), end = d_ptr->mPayloads.end(); it != end; ++it) {
+    for (auto it = d_ptr->mPayloads.begin(), end = d_ptr->mPayloads.end(); it != end; ++it) {
         result.insert(std::upper_bound(result.begin(), result.end(), it->metaTypeId), it->metaTypeId);
     }
     return result;
