@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2013 Daniel Vrátil <dvratil@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "searchresultjob_p.h"
@@ -29,7 +16,7 @@ namespace Akonadi
 class SearchResultJobPrivate : public Akonadi::JobPrivate
 {
 public:
-    SearchResultJobPrivate(SearchResultJob *parent);
+    explicit SearchResultJobPrivate(SearchResultJob *parent);
 
     QVector<QByteArray> rid;
     QByteArray searchId;
@@ -51,7 +38,7 @@ SearchResultJobPrivate::SearchResultJobPrivate(SearchResultJob *parent)
 {
 }
 
-}
+} // namespace Akonadi
 
 using namespace Akonadi;
 
