@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "agenttypemodel.h"
@@ -31,7 +18,7 @@ using namespace Akonadi;
 class Q_DECL_HIDDEN AgentTypeModel::Private
 {
 public:
-    Private(AgentTypeModel *parent)
+    explicit Private(AgentTypeModel *parent)
         : mParent(parent)
     {
         mTypes = AgentManager::self()->types();
@@ -71,12 +58,12 @@ AgentTypeModel::~AgentTypeModel()
     delete d;
 }
 
-int AgentTypeModel::columnCount(const QModelIndex &) const
+int AgentTypeModel::columnCount(const QModelIndex & /*parent*/) const
 {
     return 1;
 }
 
-int AgentTypeModel::rowCount(const QModelIndex &) const
+int AgentTypeModel::rowCount(const QModelIndex & /*parent*/) const
 {
     return d->mTypes.count();
 }
@@ -117,7 +104,7 @@ QVariant AgentTypeModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
-QModelIndex AgentTypeModel::index(int row, int column, const QModelIndex &) const
+QModelIndex AgentTypeModel::index(int row, int column, const QModelIndex & /*parent*/) const
 {
     if (row < 0 || row >= d->mTypes.count()) {
         return QModelIndex();
@@ -130,7 +117,7 @@ QModelIndex AgentTypeModel::index(int row, int column, const QModelIndex &) cons
     return createIndex(row, column);
 }
 
-QModelIndex AgentTypeModel::parent(const QModelIndex &) const
+QModelIndex AgentTypeModel::parent(const QModelIndex & /*child*/) const
 {
     return QModelIndex();
 }
