@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2007 Bruno Virlet <bruno.virlet@gmail.com>
-    Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2007 Bruno Virlet <bruno.virlet@gmail.com>
+    SPDX-FileCopyrightText: 2009 Stephen Kelly <steveire@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "entitymimetypefiltermodel.h"
@@ -36,7 +23,7 @@ namespace Akonadi
 class EntityMimeTypeFilterModelPrivate
 {
 public:
-    EntityMimeTypeFilterModelPrivate(EntityMimeTypeFilterModel *parent)
+    explicit EntityMimeTypeFilterModelPrivate(EntityMimeTypeFilterModel *parent)
         : q_ptr(parent)
         , m_headerGroup(EntityTreeModel::EntityTreeHeaders)
     {
@@ -53,7 +40,7 @@ public:
     EntityTreeModel::HeaderGroup m_headerGroup;
 };
 
-}
+} // namespace Akonadi
 
 EntityMimeTypeFilterModel::EntityMimeTypeFilterModel(QObject *parent)
     : QSortFilterProxyModel(parent)
@@ -176,10 +163,11 @@ QModelIndexList EntityMimeTypeFilterModel::match(const QModelIndex &start, int r
 
     QModelIndexList list;
     QModelIndex proxyIndex;
-    foreach (const QModelIndex &idx, sourceModel()->match(mapToSource(start), role, value, hits, flags)) {
+    const auto matches = sourceModel()->match(mapToSource(start), role, value, hits, flags);
+    for (const auto &idx: matches) {
         proxyIndex = mapFromSource(idx);
         if (proxyIndex.isValid()) {
-            list << proxyIndex;
+            list.push_back(proxyIndex);
         }
     }
 
