@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Daniel Vrátil <dvratil@redhat.com>
+    SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_TAGMODEL_H
@@ -25,7 +12,6 @@
 #include "akonadicore_export.h"
 #include "tag.h"
 
-class KJob;
 
 namespace Akonadi
 {
@@ -51,7 +37,7 @@ public:
         EndRole = 65535
     };
 
-    explicit TagModel(Monitor *recorder, QObject *parent);
+    explicit TagModel(Monitor *recorder, QObject *parent = nullptr);
     ~TagModel() override;
 
     Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -74,7 +60,7 @@ protected:
     Q_DECLARE_PRIVATE(TagModel)
     TagModelPrivate *d_ptr;
 
-    TagModel(Monitor *recorder, TagModelPrivate *dd, QObject *parent = nullptr);
+    TagModel(Monitor *recorder, TagModelPrivate *dd, QObject *parent);
 
 Q_SIGNALS:
     void populated();
@@ -84,13 +70,6 @@ private:
     bool insertColumns(int column, int count, const QModelIndex &index = QModelIndex()) override;
     bool removeColumns(int column, int count, const QModelIndex &index = QModelIndex()) override;
     bool removeRows(int row, int count, const QModelIndex &index = QModelIndex()) override;
-
-    Q_PRIVATE_SLOT(d_func(), void fillModel())
-    Q_PRIVATE_SLOT(d_func(), void tagsFetched(const Akonadi::Tag::List &tags))
-    Q_PRIVATE_SLOT(d_func(), void tagsFetchDone(KJob *job))
-    Q_PRIVATE_SLOT(d_func(), void monitoredTagAdded(const Akonadi::Tag &tag))
-    Q_PRIVATE_SLOT(d_func(), void monitoredTagRemoved(const Akonadi::Tag &tag))
-    Q_PRIVATE_SLOT(d_func(), void monitoredTagChanged(const Akonadi::Tag &tag))
 };
 }
 
