@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Daniel Vr??til <dvratil@redhat.com>
+    SPDX-FileCopyrightText: 2014 Daniel Vr ??til <dvratil@redhat.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "tagmodel_p.h"
@@ -39,10 +26,6 @@ TagModelPrivate::TagModelPrivate(TagModel *parent)
     mTags.insert(-1, Tag());
 }
 
-TagModelPrivate::~TagModelPrivate()
-{
-}
-
 void TagModelPrivate::init(Monitor *monitor)
 {
     Q_Q(TagModel);
@@ -50,12 +33,9 @@ void TagModelPrivate::init(Monitor *monitor)
     mMonitor = monitor;
     mSession = mMonitor->session();
 
-    q->connect(mMonitor, SIGNAL(tagAdded(Akonadi::Tag)),
-               q, SLOT(monitoredTagAdded(Akonadi::Tag)));
-    q->connect(mMonitor, SIGNAL(tagChanged(Akonadi::Tag)),
-               q, SLOT(monitoredTagChanged(Akonadi::Tag)));
-    q->connect(mMonitor, SIGNAL(tagRemoved(Akonadi::Tag)),
-               q, SLOT(monitoredTagRemoved(Akonadi::Tag)));
+    q->connect(mMonitor, &Monitor::tagAdded, q, [this](const Tag &tag) { monitoredTagAdded(tag); });
+    q->connect(mMonitor, &Monitor::tagChanged, q, [this](const Tag &tag) { monitoredTagChanged(tag); });
+    q->connect(mMonitor, &Monitor::tagRemoved, q, [this](const Tag &tag) { monitoredTagRemoved(tag); });
 
     // Delay starting the job to allow unit-tests to set up fake stuff
     QTimer::singleShot(0, q, [this] { fillModel(); });
@@ -67,10 +47,8 @@ void TagModelPrivate::fillModel()
 
     TagFetchJob *fetchJob = new TagFetchJob(mSession);
     fetchJob->setFetchScope(mMonitor->tagFetchScope());
-    q->connect(fetchJob, SIGNAL(tagsReceived(Akonadi::Tag::List)),
-               q, SLOT(tagsFetched(Akonadi::Tag::List)));
-    q->connect(fetchJob, SIGNAL(finished(KJob*)),
-               q, SLOT(tagsFetchDone(KJob*)));
+    q->connect(fetchJob, &TagFetchJob::tagsReceived, q, [this](const auto &tags) { tagsFetched(tags); });
+    q->connect(fetchJob, &KJob::result, q, [this](KJob *job) { tagsFetchDone(job); });
 }
 
 QModelIndex TagModelPrivate::indexForTag(const qint64 tagId) const
@@ -89,7 +67,7 @@ QModelIndex TagModelPrivate::indexForTag(const qint64 tagId) const
     const Tag::Id parentId = tag.parent().id();
     const int row = mChildTags.value(parentId).indexOf(tag);
     if (row != -1) {
-        return q->createIndex(row, 0, (int) parentId);
+        return q->createIndex(row, 0, static_cast<int>(parentId));
     }
 
     return QModelIndex();
