@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2008 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2008 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "protocolhelper_p.h"
@@ -35,11 +22,14 @@
 #include "private/protocol_p.h"
 #include "private/externalpartstorage_p.h"
 
+#include <shared/akranges.h>
+
 #include <QFile>
 #include <QVarLengthArray>
 
 
 using namespace Akonadi;
+using namespace AkRanges;
 
 CachePolicy ProtocolHelper::parseCachePolicy(const Protocol::CachePolicy &policy)
 {
@@ -102,7 +92,8 @@ template<typename T>
 inline static Protocol::Attributes attributesToProtocolImpl(const T &entity, bool ns)
 {
     Protocol::Attributes attributes;
-    Q_FOREACH (const Attribute *attr, entity.attributes()) {
+    const auto attrs = entity.attributes();
+    for (const auto *attr : attrs) {
         attributes.insert(ProtocolHelper::encodePartIdentifier(ns ? ProtocolHelper::PartAttribute : ProtocolHelper::PartGlobal, attr->type()),
                           attr->serialized());
     }
@@ -238,14 +229,9 @@ Collection ProtocolHelper::parseCollection(const Protocol::FetchCollectionsRespo
     collection.setLocalListPreference(Collection::ListSync, parsePreference(data.syncPref()));
 
     if (!data.searchQuery().isEmpty()) {
-        auto attr = collection.attribute<PersistentSearchAttribute>(Collection::AddIfMissing);
+        auto *attr = collection.attribute<PersistentSearchAttribute>(Collection::AddIfMissing);
         attr->setQueryString(data.searchQuery());
-
-        QVector<Collection> cols;
-        cols.reserve(data.searchCollections().size());
-        foreach (auto id, data.searchCollections()) {
-            cols.push_back(Collection(id));
-        }
+        const auto cols = data.searchCollections() | Views::transform([](const auto id) { return Collection{id}; }) | Actions::toQVector;
         attr->setQueryCollections(cols);
     }
 
@@ -349,12 +335,8 @@ Protocol::ItemFetchScope ProtocolHelper::itemFetchScopeToProtocol(const ItemFetc
     Protocol::ItemFetchScope fs;
     QVector<QByteArray> parts;
     parts.reserve(fetchScope.payloadParts().size() + fetchScope.attributes().size());
-    Q_FOREACH (const QByteArray &part, fetchScope.payloadParts()) {
-        parts << ProtocolHelper::encodePartIdentifier(ProtocolHelper::PartPayload, part);
-    }
-    Q_FOREACH (const QByteArray &part, fetchScope.attributes()) {
-        parts << ProtocolHelper::encodePartIdentifier(ProtocolHelper::PartAttribute, part);
-    }
+    parts += fetchScope.payloadParts() | Views::transform(std::bind(encodePartIdentifier, PartPayload, std::placeholders::_1)) | Actions::toQVector;
+    parts += fetchScope.attributes() | Views::transform(std::bind(encodePartIdentifier, PartAttribute, std::placeholders::_1)) | Actions::toQVector;
     fs.setRequestedParts(parts);
 
     // The default scope
@@ -402,7 +384,8 @@ Protocol::ItemFetchScope ProtocolHelper::itemFetchScopeToProtocol(const ItemFetc
 ItemFetchScope ProtocolHelper::parseItemFetchScope(const Protocol::ItemFetchScope &fetchScope)
 {
     ItemFetchScope ifs;
-    Q_FOREACH (const auto &part, fetchScope.requestedParts()) {
+    const auto parts = fetchScope.requestedParts();
+    for (const auto &part : parts) {
         if (part.startsWith("PLD:")) {
             ifs.fetchPayloadPart(part.mid(4), true);
         } else if (part.startsWith("ATR:")) {
