@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2018 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "akremotelog.h"
@@ -93,11 +80,11 @@ private Q_SLOTS:
             return;
         }
 
-        connect(mAkonadiConsoleInterface.get(), SIGNAL(enabledChanged(bool)),
+        connect(mAkonadiConsoleInterface.get(), SIGNAL(enabledChanged(bool)),  // clazy:exclude=old-style-connect
                 this, SLOT(onAkonadiConsoleLoggingEnabled(bool)));
 
         QTimer::singleShot(0, this, [this]() {
-            auto watcher = new QDBusPendingCallWatcher(mAkonadiConsoleInterface->asyncCall(QStringLiteral("enabled")));
+            auto *watcher = new QDBusPendingCallWatcher(mAkonadiConsoleInterface->asyncCall(QStringLiteral("enabled")));
             connect(watcher, &QDBusPendingCallWatcher::finished,
                     this, [this](QDBusPendingCallWatcher *watcher) {
                         watcher->deleteLater();
@@ -110,7 +97,7 @@ private Q_SLOTS:
         });
     }
 
-    void serviceUnregistered(const QString &)
+    void serviceUnregistered(const QString & /*unused*/)
     {
         onAkonadiConsoleLoggingEnabled(false);
         mAkonadiConsoleInterface.reset();
@@ -149,7 +136,7 @@ private:
 
     static void categoryFilter(QLoggingCategory *cat)
     {
-        const auto that = self();
+        auto *const that = self();
         if (!that) {
             return;
         }
@@ -166,7 +153,7 @@ private:
 
     static void dbusLogger(QtMsgType type, const QMessageLogContext &ctx, const QString &msg)
     {
-        const auto that = self();
+        auto *const that = self();
         if (!that) {
             return;
         }
@@ -197,7 +184,7 @@ private:
 
 RemoteLogger *RemoteLogger::sInstance = nullptr;
 
-}
+} // namespace
 
 void akInitRemoteLog()
 {
