@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006-2008 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006-2008 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "agentinstancewidget.h"
@@ -50,7 +37,7 @@ struct Icons {
     QPixmap readyPixmap, syncPixmap, errorPixmap, offlinePixmap;
 };
 
-Q_GLOBAL_STATIC(Icons, s_icons)
+Q_GLOBAL_STATIC(Icons, s_icons) // NOLINT(readability-redundant-member-init)
 
 // called as a Qt post routine, to prevent pixmap leaking
 void iconsEarlyCleanup()
@@ -67,6 +54,7 @@ static const int s_delegatePaddingSize = 7;
 
 class AgentInstanceWidgetDelegate : public QAbstractItemDelegate
 {
+    Q_OBJECT
 public:
     explicit AgentInstanceWidgetDelegate(QObject *parent = nullptr);
 
@@ -74,7 +62,7 @@ public:
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
-}
+} // namespace Internal
 
 using Akonadi::Internal::AgentInstanceWidgetDelegate;
 
@@ -84,7 +72,7 @@ using Akonadi::Internal::AgentInstanceWidgetDelegate;
 class Q_DECL_HIDDEN AgentInstanceWidget::Private
 {
 public:
-    Private(AgentInstanceWidget *parent)
+    explicit Private(AgentInstanceWidget *parent)
         : mParent(parent)
         , mView(nullptr)
         , mModel(nullptr)
@@ -155,18 +143,20 @@ AgentInstanceWidget::AgentInstanceWidget(QWidget *parent)
     d->mModel = new AgentInstanceModel(this);
 
     d->proxy = new AgentFilterProxyModel(this);
+    d->proxy->setDynamicSortFilter(true);
+    d->proxy->sort(0);
+    d->proxy->setSortCaseSensitivity(Qt::CaseInsensitive);
     d->proxy->setSourceModel(d->mModel);
     d->mView->setModel(d->proxy);
 
     d->mView->selectionModel()->setCurrentIndex(d->mView->model()->index(0, 0), QItemSelectionModel::Select);
     d->mView->scrollTo(d->mView->model()->index(0, 0));
 
-    connect(d->mView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(currentAgentInstanceChanged(QModelIndex,QModelIndex)));
+    connect(d->mView->selectionModel(), &QItemSelectionModel::currentChanged,
+            this, [this](const auto &tl, const auto &br) { d->currentAgentInstanceChanged(tl, br); });
     connect(d->mView, &QListView::doubleClicked,
             this, [this](const QModelIndex &currentIndex) { d->currentAgentInstanceDoubleClicked(currentIndex); });
-    connect(d->mView, SIGNAL(clicked(QModelIndex)),
-            this, SLOT(currentAgentInstanceClicked(QModelIndex)));
+    connect(d->mView, &QListView::clicked, this, [this](const auto &mi) { d->currentAgentInstanceClicked(mi); });
 }
 
 AgentInstanceWidget::~AgentInstanceWidget()
@@ -297,6 +287,6 @@ QSize AgentInstanceWidgetDelegate::sizeHint(const QStyleOptionViewItem &option,
     return QSize(1, qMax(iconHeight, textHeight));    //any width,the view will give us the whole thing in list mode
 }
 
-}
+} // namespace Akonadi
 
-#include "moc_agentinstancewidget.cpp"
+#include "agentinstancewidget.moc"
