@@ -1,21 +1,8 @@
 /*
-    Copyright 2008 Ingo Klöcker <kloecker@kde.org>
-    Copyright 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2008 Ingo Klöcker <kloecker@kde.org>
+    SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectiondialog.h"
@@ -116,11 +103,10 @@ public:
         mParent->connect(filterCollectionLineEdit, &QLineEdit::textChanged,
                          mParent, [this](const QString &str) { slotFilterFixedString(str); });
 
-        mParent->connect(mView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                         mParent, SLOT(slotSelectionChanged()));
-
-        mParent->connect(mView, SIGNAL(doubleClicked(QModelIndex)),
-                         mParent, SLOT(slotDoubleClicked()));
+        mParent->connect(mView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                         mParent, [this]() { slotSelectionChanged(); });
+        mParent->connect(mView, qOverload<const QModelIndex &>(&QAbstractItemView::doubleClicked),
+                         mParent, [this]() { slotDoubleClicked(); });
 
         mSelectionHandler = new AsyncSelectionHandler(mFilterCollection, mParent);
         mParent->connect(mSelectionHandler, &AsyncSelectionHandler::collectionAvailable,
@@ -157,7 +143,7 @@ public:
         }
     }
 
-    void writeConfig()
+    void writeConfig() const
     {
         KConfig config(QStringLiteral("akonadi_contactrc"));
         KConfigGroup group(&config, QStringLiteral("CollectionDialog"));
@@ -233,7 +219,7 @@ void CollectionDialog::Private::changeCollectionDialogOptions(CollectionDialogOp
         mNewSubfolderButton->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
         mNewSubfolderButton->setToolTip(i18n("Create a new subfolder under the currently selected folder"));
         mNewSubfolderButton->setEnabled(false);
-        connect(mNewSubfolderButton, SIGNAL(clicked(bool)), mParent, SLOT(slotAddChildCollection()));
+        connect(mNewSubfolderButton, &QPushButton::clicked, mParent, [this]() { slotAddChildCollection(); });
     }
     mKeepTreeExpanded = (options & KeepTreeExpanded);
     if (mKeepTreeExpanded) {
