@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2008 Thomas McGuire <thomas.mcguire@gmx.net>
-    Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2008 Thomas McGuire <thomas.mcguire@gmx.net>
+    SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectionstatisticsdelegate.h"
@@ -55,7 +42,7 @@ public:
     QColor mSelectedUnreadColor;
     QColor mDeselectedUnreadColor;
 
-    CollectionStatisticsDelegatePrivate(QAbstractItemView *treeView)
+    explicit CollectionStatisticsDelegatePrivate(QAbstractItemView *treeView)
         : parent(treeView)
     {
         updateColor();
@@ -90,7 +77,7 @@ public:
     }
 };
 
-}
+} // namespace Akonadi
 
 CollectionStatisticsDelegate::CollectionStatisticsDelegate(QAbstractItemView *parent)
     : QStyledItemDelegate(parent)
@@ -178,7 +165,7 @@ void CollectionStatisticsDelegate::initStyleOption(QStyleOptionViewItem *option,
 class PainterStateSaver
 {
 public:
-    PainterStateSaver(QPainter *painter)
+    explicit PainterStateSaver(QPainter *painter)
     {
         mPainter = painter;
         mPainter->save();
@@ -246,9 +233,7 @@ void CollectionStatisticsDelegate::paint(QPainter *painter,
     qint64 totalSize = 0;
     bool needRecursiveCounts = false;
     bool needTotalSize = false;
-    if (d->drawUnreadAfterFolder && index.column() == 0) {
-        needRecursiveCounts = true;
-    } else if ((index.column() == 1 || index.column() == 2)) {
+    if ((d->drawUnreadAfterFolder && index.column() == 0) || (index.column() == 1 || index.column() == 2)) {
         needRecursiveCounts = true;
     } else if (index.column() == 3 && !expanded) {
         needTotalSize = true;
